@@ -1,38 +1,38 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/Editor/RequireEmacsFileVariables.pm $
-#     $Date: 2008-05-18 19:30:24 -0500 (Sun, 18 May 2008) $
-#   $Author: clonezone $
-# $Revision: 2372 $
+#     $Date: 2006-11-15 12:02:15 -0600 (Wed, 15 Nov 2006) $
+#   $Author: chrisdolan $
+# $Revision: 867 $
 ########################################################################
 
 package Perl::Critic::Policy::Editor::RequireEmacsFileVariables;
 
-use 5.006;
 use strict;
 use warnings;
-
-use Readonly;
-
-use Perl::Critic::Utils qw{ :severities };
+use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_002';
-
-# This constant is hard-coded in emacs file.el
-Readonly::Scalar my $LOOK_BYTES_FROM_END => 3000;
+our $VERSION = 0.1;
 
 #---------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC =>
-    'Use Emacs file variables to declare coding style';
-Readonly::Scalar my $expl => 'Emacs can read per-file settings';
+my $desc = 'Use Emacs file variables to declare coding style';
+my $expl = 'Emacs can read per-file settings';
 
 #---------------------------------------------------------------------------
 
-sub default_severity     { return $SEVERITY_LOW }
-sub default_themes       { return qw< more readability editor > }
-sub applies_to           { return 'PPI::Document' }
-sub supported_parameters { return () }
+sub default_severity { return $SEVERITY_LOW }
+sub default_themes   { return qw(more readability editor) }
+sub applies_to       { return 'PPI::Document' }
+
+#---------------------------------------------------------------------------
+
+sub new {
+    my ( $class, %config ) = @_;
+    my $self = bless {}, $class;
+
+    return $self;
+}
 
 #---------------------------------------------------------------------------
 
@@ -42,7 +42,7 @@ sub violates {
     my $code = $doc->serialize();
 
     ## Look for first line file vars.  Example:
-    # #! /usr/bin/perl -w -*- cperl; cperl-indent-level: 4 -*-
+    #! /usr/bin/perl -w -*- mode: cperl; cperl-indent-level: 4 -*-
 
     my $one_line_local_var = qr/-[*]- .* -[*]-/xms;
 
@@ -57,9 +57,9 @@ sub violates {
 
     ## Look for end of doc file vars  Example:
     #  Local Variables:
-    #   mode: cperl
+    #   mode: cperl-mode
     #  End:
-    my $last_page = substr $code, -$LOOK_BYTES_FROM_END;
+    my $last_page = substr $code, -3000;
 
     # Remove anything not on the last page, as delimited by "^L", aka
     # "\f", aka formfeed.
@@ -68,17 +68,13 @@ sub violates {
     # This regex is transliterated from emacs22 files.el
     # Note that the [ \t]* before "End:" appears to be wrong, but is
     # added for compatibility
+    return if $last_page =~ m/
+                              ^ ([^\n]*) Local [ ] Variables: [ \t]* ([^\n]*) $
+                              .*?
+                              ^ \1 [ \t]* End: [ \t]* \2 $
+                            /ixms;
 
-    ## Due to the backreferences, this is almost impossible to subdivide.
-    ## no critic (ProhibitComplexRegexes)
-    return if $last_page =~ m<
-        ^ ([^\n]*) Local [ ] Variables: [ \t]* ([^\n]*) $
-        .*?
-        ^ \1 [ \t]* End: [ \t]* \2 $
-    >ixms;
-    ## use critic
-
-    return $self->violation( $DESC, $expl, $doc );
+    return $self->violation( $desc, $expl, $doc );
 }
 
 1;
@@ -89,16 +85,11 @@ __END__
 
 =pod
 
-=for stopwords elisp emacs formfeed syntaxes files.el
+=for stopwords elisp syntaxes files.el
 
 =head1 NAME
 
-Perl::Critic::Policy::Editor::RequireEmacsFileVariables - Per-file editor settings.
-
-=head1 AFFILIATION
-
-This policy is part of L<Perl::Critic::More>, a bleeding edge supplement to
-L<Perl::Critic>.
+Perl::Critic::Policy::Editor::RequireEmacsFileVariables;
 
 =head1 DESCRIPTION
 
@@ -149,7 +140,7 @@ Michael Wolf <MichaelRWolf@att.net>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan
+Copyright (c) 2006 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -157,8 +148,6 @@ can be found in the LICENSE file included with this module.
 
 =cut
 
-
-
 # Local Variables:
 #   mode: cperl
 #   cperl-indent-level: 4
@@ -166,4 +155,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 expandtab
